@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ class AbstractImporter;
 class PluginUtilData
 {
 public:
-    PluginUtilData()
-    {
-    }
+    PluginUtilData() = default;
 
     QStringList mExtraInfo;
     QString mIdentifier;
@@ -29,9 +27,7 @@ public:
 class ImportMailPluginManagerInfo
 {
 public:
-    ImportMailPluginManagerInfo()
-    {
-    }
+    ImportMailPluginManagerInfo() = default;
 
     QString metaDataFileName;
     PluginUtilData pluginData;
